@@ -1,4 +1,5 @@
 import argparse
+import sys
 from pyspark.sql import SparkSession
 
 # Used for high-speed ingest from Databricks. Is meant to be run as part of a Databricks job.
@@ -6,6 +7,7 @@ def run(**kwargs):
     spark = SparkSession.builder.getOrCreate()
 
     print("KWARGS", kwargs)
+    print("sys.argv", sys.argv)
 
     df = spark.sql(f"""{kwargs['sql_query']}""")
     df.write \
